@@ -1,10 +1,5 @@
 /* ============================================================
 *
-* This file is part of the KDE project
-*
-* Date        : 2008-11-15
-* Description : Preview image viewer that can handle a selection.
-*
 * SPDX-FileCopyrightText: 2008 Kare Sars <kare dot sars at iki dot fi>
 *
 * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
@@ -20,6 +15,9 @@
 namespace KSaneIface
 {
 
+/*
+ * Preview image viewer that can handle a selection.
+ */
 class KSaneViewer : public QGraphicsView
 {
     Q_OBJECT
@@ -35,6 +33,9 @@ public:
 
     QSize sizeHint() const override;
 
+    int currentImageHeight() const;
+    int currentImageWidth() const;
+
 public Q_SLOTS:
 
     void setTLX(float ratio);
