@@ -1,9 +1,4 @@
 /* ============================================================
- *
- * This file is part of the KDE project
- *
- * Date        : 2007-09-13
- * Description : Sane interface for KDE
  *
  * SPDX-FileCopyrightText: 2007-2008 Kare Sars <kare.sars@iki .fi>
  *
@@ -36,10 +31,12 @@ public:
     /**
     * Create a gamma display.
     * \param parent parent widget
-    * \param tbl the gamma table
+    * \param brightness the brightness value
+    * \param contrast the contrast value
+    * \param gamma the gamma value
     * \param maxValue the maximum value
     */
-    GammaDisp(QWidget *parent, QVector<int> *tbl, int maxValue);
+    GammaDisp(QWidget *parent, int *brightness, int *contrast, int *gamma, int maxValue);
     ~GammaDisp() {}
 
     QSize sizeHint() const override;
@@ -54,9 +51,11 @@ protected:
 
 private:
 
-    QVector<int> *m_gammaTable;
-    QColor        m_gammaColor;
-    int           m_maxValue;
+    int    *m_brightness;
+    int    *m_contrast;
+    int    *m_gamma;
+    QColor  m_gammaColor;
+    int     m_maxValue;
 };
 
 }  // NameSpace KSaneIface
